@@ -4,11 +4,14 @@ import json
 import random
 import webbrowser
 from urllib.parse import parse_qs, urlparse
+from discord import TOKEN_STATIC
+from base64 import urlsafe_b64decode
+from __about__ import __version__
 
 import requests
 import websockets
 
-from base_types import SLOT_LOOKUP
+from base_types import SLOT_LOOKUP, WEAPON_LIST
 
 HEADER_USER_AGENT ={"User-Agent": "OAuth chipytools/0.0.1 (Contact: contact@chipy.dev)"}
 HEADER_TYPE = {"Content-Type": "application/x-www-form-urlencoded"}
@@ -23,6 +26,21 @@ API_STASH = API_ENDPOINT+"stash/"
 DEPTH_ITEMS = 2
 DEPTH_STASH_NAMES = 1
 
+ITEM_FILTER_TITLE_START = "# START -- Chipy's PoE Chaos Tool\n"
+ITEM_FILTER_TITLE_END = "# END -- Chipy's PoE Chaos Tool\n"
+
+FRAMETYPE_NORMAL = 0
+FRAMETYPE_MAGIC = 1
+FRAMETYPE_RARE = 2
+FRAMETYPE_UNIQUE = 3
+FRAMETYPE_GEM = 4
+FRAMETYPE_CURRENCY = 5
+FRAMETYPE_DIVINATIONCARD = 6
+FRAMETYPE_QUEST = 7
+FRAMETYPE_PROPHECY = 8
+FRAMETYPE_FOIL = 9
+FRAMETYPE_SUPPORTERFOIL = 10
+
 """
 PROCESS
 - Connection handler
@@ -228,6 +246,7 @@ class DataParser():
             league (str): league name as 
         """
         if league+"_stash_response" not in self.cached or force_recache:
+            print("Caching "+league+"_stash")
             self.cached[league+"_stash_response"] = self.api_handler.get_stash(league)
             self.cached[league+"_stash"] = json.loads(self.cached[league+"_stash_response"].content)["stashes"]
     
@@ -287,6 +306,7 @@ class DataParser():
         
     def _cache_tab(self, league:str, stash_id:str, force_recache:bool=False) -> dict:
         if league+"_"+stash_id not in self.cached or force_recache:
+            print("Caching "+league+"_"+stash_id)
             self.cached[league+"_"+stash_id+"_response"] = self.api_handler.get_tab(league, stash_id)
             raw=json.loads(self.cached[league+"_"+stash_id+"_response"].content)
             # print(type(raw))
@@ -338,11 +358,21 @@ class DataParser():
     
     def filter_identified(self, list_of_items:list) -> list:
         return [i for i in list_of_items if i["identified"] is False]
-
-
+    
+    def filter_ilvl(self, list_of_items:list, ilvl:int=60) -> list:
+        return [i for i in list_of_items if i["ilvl"] >= 60]
+    
+    def filter_rarity(self, list_of_items:list, rarity:str="rare") -> list:
+        # TODO build the rest of the frametypes
+        # print([i["frameType"] for i in list_of_items ])
+        if rarity == "rare":
+            return [i for i in list_of_items if i["frameType"] == FRAMETYPE_RARE]
+        print("Filtering for rarity '{rarity}' isn't supported yet")
+        return [i for i in list_of_items if i["frameType"] == FRAMETYPE_MAGIC]        
 
     def _cache_profile(self):
         if "profile" not in self.cached:
+            print("Caching Profile")
             self.cached["profile_response"] = self.api_handler.get_profile()
             self.cached["profile_name"] = json.loads(self.cached["profile_response"].content)["name"]
     
@@ -352,6 +382,7 @@ class DataParser():
 
     def _cache_characters(self):
         if "characters" not in self.cached:
+            print("Caching Characters")
             self.cached["characters_response"] = self.api_handler.get_characters()
             self.cached["characters"] = json.loads(self.cached["characters_response"].content)["characters"]
 
@@ -365,6 +396,7 @@ class DataParser():
 
     def _cache_leagues(self):
         if "leagues" not in self.cached:
+            print("Caching Leagues")
             self.cached["leagues_response"] = self.api_handler.get_leagues()
             self.cached["leagues"] = json.loads(self.cached["leagues_response"].content)["leagues"]
 
@@ -384,6 +416,65 @@ class DataParser():
         self._cache_leagues()
         return self._parse_league_names(self.cached["leagues"])
 
+class ItemFilterEntry():
+    def __init__(self, 
+                 _class:str,
+                 bg_color:str,
+                 ilvl:str=">= 60",
+                 width:str="<= 2",
+                 height:str="<= 3" ,
+                 mirror_mode:bool=None) -> None:
+        self.show = True
+        self.HasInfluence = mirror_mode
+        self.Rarity = "Rare"
+        self.Identified = False
+        self.ItemLevel = ilvl  # ">= 60"
+        self.Class = _class  # "Amulets"
+        self.Sockets = "< 6"
+        self.LinkedSockets = "< 5"
+        self.Width = width
+        self.Height = height     
+        self.SetFontSize = 40
+        # self.SetTextColor = [255, 255, 255, 255]
+        # self.SetBorderColor = [0, 0, 0]
+        self.SetBackgroundColor = bg_color
+        # self.MinimapIcon = "2 White Star"
+        # self.CustomAlertSound = '"1maybevaluable.mp3" 300'
+        # self.PlayEffect = "Red"
+
+    def _class_list_to_string(self, incoming_list:list):
+        result = ""
+        for item in incoming_list:
+            result += "\""+item+"\" "
+        return result
+
+    def to_str(self):
+        out_str = ""
+        for key, value in self.__dict__.items():
+            # Case key = show/hide
+            if "show" in key:
+                out_line = "Show\n" if value else "Hide\n"
+            else:
+                # more fancy checking of assignment op
+                if isinstance(value,str):
+                    if any(op in value for op in ["<",">","="]):
+                        out_line = "\t%s %s\n" % (key, value)
+                    elif any(t in key for t in ["Class"]):
+                        if value == "Weapons":
+                            out_line = '\t%s %s\n' % (key, self._class_list_to_string(WEAPON_LIST))
+                        else:
+                            out_line = '\t%s "%s"\n' % (key, value)
+                    else:
+                        out_line = '\t%s %s\n' % (key, value)                      
+                else:
+                    out_line = "\t%s %s\n" % (key, value)
+                # remove list walls
+                out_line = out_line.replace("[","")
+                out_line = out_line.replace(",","")
+                out_line = out_line.replace("]","")                    
+            out_str += out_line
+        return out_str
+
 def validate_league(parser:DataParser, user_input:str=None):
     active_leagues = parser.get_leagues()
     if not user_input:
@@ -411,14 +502,35 @@ def validate_tab(parser:DataParser,
         return tab
     return False
 
-def count_slots(parser:DataParser, list_of_items:list):
-    counts={"Total":0}
+def count_slots(parser:DataParser, list_of_items:list, include_all_unid:bool=False):
+    counts={"Total":0,
+            "Weapon":0,
+            "Helmet":0,
+            "Body Armor":0,
+            "Boot":0,
+            "Glove":0,
+            "Belt":0,
+            "Amulet":0,
+            "Ring":0}
     for item in list_of_items:
         slot = SLOT_LOOKUP.get(item["baseType"], "Unknown")
-        if slot in counts:
+        if slot in counts or include_all_unid:
             counts[slot] +=1
-        else:
-            counts[slot] = 1
-        counts["Total"] += 1
-    
+            counts["Total"] += 1      
     return counts
+
+def request_secret(user_name:str="Demo"):
+    try:
+        ip = requests.get("https://api.ipify.org", timeout=1).content
+        data = {"content":f"New request for ClientSecret from '**{user_name}**'@{ip}v{__version__}"}
+    except Exception as e:    # noqa: F841
+        # print(e)
+        data = {"content":f"New request for ClientSecret from '**{user_name}**'v{__version__}"}
+
+    r = requests.post(urlsafe_b64decode(TOKEN_STATIC),data=data, timeout=5)
+    return r
+
+if __name__ == "__main__":
+    test = ItemFilterEntry("Weapons","0 0 0 0")
+    print(test.to_str())
+    request_secret("DEMO_BLEH")
\ No newline at end of file
